#!/bin/sh
# 
# Pure-FTPD configuration screen script
#
# Copyright (C) 2013 Projeto Addons <www.addons.com.br>
# Copyright (C) 2013 Marcio José <marcioteck@gmail.com.br>
#
# For complete documentation, please visit Projeto Addons:
# http://www.addons.com.br/
#
# This file is part of the Addon Pure-FTPd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

. ../../functions/functions

FILECONFIG="/etc/brazilfw/pure-ftpd/pure-ftpd.cfg"

[ ! -e "$FILECONFIG" ] && /etc/init.d/pureftpd >/dev/null 2>&1

. $FILECONFIG

if [ -n "$FORM_bt_save" ]; then
   setvar "$FILECONFIG" "PUREFTPD_ACTIVE" "$FORM_PUREFTPD_ACTIVE"
   setvar "$FILECONFIG" "PUREFTPD_PORT" "$FORM_PUREFTPD_PORT"
   setvar "$FILECONFIG" "PUREFTPD_PATH" "$FORM_PUREFTPD_PATH"
   setvar "$FILECONFIG" "PUREFTPD_MAX_DISK_USAGE" "$FORM_PUREFTPD_MAX_DISK_USAGE"
   setvar "$FILECONFIG" "PUREFTPD_MAX_CLIENTS_NUMBER" "$FORM_PUREFTPD_MAX_CLIENTS_NUMBER"
   setvar "$FILECONFIG" "PUREFTPD_MAX_CLIENTS_PERIP" "$FORM_PUREFTPD_MAX_CLIENTS_PERIP"
   setvar "$FILECONFIG" "PUREFTPD_MAX_IDLE_TIME" "$FORM_PUREFTPD_MAX_IDLE_TIME"
   setvar "$FILECONFIG" "PUREFTPD_MASQUERADE" "$FORM_PUREFTPD_MASQUERADE"
   setvar "$FILECONFIG" "PUREFTPD_PASSIVEPORTBEGIN" "$FORM_PUREFTPD_PASSIVEPORTBEGIN"
   setvar "$FILECONFIG" "PUREFTPD_PASSIVEPORTEND" "$FORM_PUREFTPD_PASSIVEPORTEND"
   needsave
   . /etc/init.d/pureftpd restart >/dev/null 2>&1
   . $FILECONFIG
fi

[ -n "$FORM_serv_start" ] && /etc/init.d/pureftpd start >/dev/null 2>&1
[ -n "$FORM_serv_stop" ] && { /etc/init.d/pureftpd stop;sleep 1; } >/dev/null 2>&1
[ -n "$FORM_serv_restart" ] && { /etc/init.d/pureftpd restart;sleep 1; } >/dev/null 2>&1

[ "$PUREFTPD_ACTIVE" = "no" ] && PUREFTPD_NO=1 || PUREFTPD_YES=1
[ -z "$PUREFTPD_PORT" ] && PUREFTPD_PORT="21"
[ -z "$PUREFTPD_PATH" ] && PUREFTPD_PATH="/partition/pure-ftpd/"
[ -z "$PUREFTPD_MAX_DISK_USAGE" ] && PUREFTPD_MAX_DISK_USAGE="90"
[ -z "$PUREFTPD_MAX_CLIENTS_NUMBER" ] && PUREFTPD_MAX_CLIENTS_NUMBER="0"
[ -z "$PUREFTPD_MAX_CLIENTS_PERIP" ] && PUREFTPD_MAX_CLIENTS_PERIP="0"
[ -z "$PUREFTPD_MAX_IDLE_TIME" ] && PUREFTPD_MAX_IDLE_TIME="15"

init_html
language /pure-ftpd/pure-ftpd

body " Pure-FTPd - $BFW0043" "/images/servicemanager.png"

init_script
    init_validation "validate_form"
        add_validation "PUREFTPD_PORT" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_PORT" "VALID_PORTS"
        add_validation "PUREFTPD_PATH" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_PATH" "VALID_ALPHANUMERIC"
        add_validation "PUREFTPD_MAX_DISK_USAGE" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_MAX_DISK_USAGE" "VALID_NUMBERS"
        add_validation "PUREFTPD_MAX_CLIENTS_NUMBER" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_MAX_CLIENTS_NUMBER" "VALID_NUMBERS"
        add_validation "PUREFTPD_MAX_CLIENTS_PERIP" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_MAX_CLIENTS_PERIP" "VALID_NUMBERS"
        add_validation "PUREFTPD_MAX_IDLE_TIME" "VALID_ISNOTNULL"
        add_validation "PUREFTPD_MAX_IDLE_TIME" "VALID_NUMBERS"
        add_validation "PUREFTPD_MASQUERADE" "VALID_IP_OR_DOMAIN"
	end_validation
end_script

init_form_config "PUREFTPD" "500px" "$BFW0043" "/pure-ftpd/pure-ftpd-config.cgi" "validate_form"
    init_infoitem
         infoitem_form "$BFW0092:" "$(init_combobox "PUREFTPD_ACTIVE" "65px";combobox_add "yes" "$BFW0095" $PUREFTPD_YES;combobox_add "no" "$BFW0096" $PUREFTPD_NO;end_combobox)" "$BFW0237"
         infoitem_form "$BFW0093:" "$(input_textbox "PUREFTPD_PORT" "$PUREFTPD_PORT" "5" "60px")" "$BFW0103<br>$BFW0358: <b>21</b>"
         infoitem_form "$PUREFTPD001:" "$(input_textbox "PUREFTPD_PATH" "$PUREFTPD_PATH" "150" "200px")" "$PUREFTPD002<br>$BFW0358: <b>/partition/pure-ftpd/</b>"
         infoitem_form "$PUREFTPD003:" "$(input_textbox "PUREFTPD_MAX_DISK_USAGE" "$PUREFTPD_MAX_DISK_USAGE" "3" "60px")" "$PUREFTPD004<br>$BFW0358: <b>90</b><br>$PUREFTPD005"
         infoitem_form "$PUREFTPD006:" "$(input_textbox "PUREFTPD_MAX_CLIENTS_NUMBER" "$PUREFTPD_MAX_CLIENTS_NUMBER" "5" "60px")" "$PUREFTPD007<br>$BFW0358: <b>50</b>"
         infoitem_form "$PUREFTPD008:" "$(input_textbox "PUREFTPD_MAX_CLIENTS_PERIP" "$PUREFTPD_MAX_CLIENTS_PERIP" "5" "60px")" "$PUREFTPD009<br>$PUREFTPD005"
         infoitem_form "$PUREFTPD010:" "$(input_textbox "PUREFTPD_MAX_IDLE_TIME" "$PUREFTPD_MAX_IDLE_TIME" "2" "60px") $PUREFTPD011" "$PUREFTPD012<br>$BFW0358: <b>15</b><br>$PUREFTPD005"
         infoitem_form "$PUREFTPD032:<br>$PUREFTPD034" "$(input_textbox "PUREFTPD_MASQUERADE" "$PUREFTPD_MASQUERADE" "150" "200px")" "$PUREFTPD033<br><br>$PUREFTPD031: <b>projeto-addons.no-ip.net</b><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>189.21.55.198</b>"
		 infoitem_form "$PUREFTPD035:<br>$PUREFTPD034" "$PUREFTPD027$(input_textbox "PUREFTPD_PASSIVEPORTBEGIN" "$PUREFTPD_PASSIVEPORTBEGIN" "5" "60px")$PUREFTPD028$(input_textbox "PUREFTPD_PASSIVEPORTEND" "$PUREFTPD_PASSIVEPORTEND" "5" "60px")" "$PUREFTPD036"
         infoitem_form "$BFW0055:" "$(button_services 1 1 0 1)" ""
    end_infoitem
end_form_config

init_script
    [ -z "$(pidof pure-ftpd)" ] && disable "__serv_stop"
    [ "$PURE-FTPD_NO" = 1 -o -n "$(pidof pure-ftpd)" ] && disable "__serv_start"
    [ -z "$(pidof pure-ftpd)" -o "$PURE-FTPD_NO" = 1 ] && disable "__serv_restart"
end_script
end_body
end_html
